@@ -1,18 +1,11 @@
-
-from __future__ import print_function
-
 import sys
 import os
 from glob import glob
 import traceback
 import types
 
-if sys.version_info[0] == 2:
-    from Tkinter import *
-    import tkMessageBox
-else:
-    from tkinter import *
-    import tkinter.messagebox as tkMessageBox
+from tkinter import *
+import tkinter.messagebox as tkMessageBox
 
 import Pmw
 
@@ -99,9 +92,7 @@ class CleanWizard(ActionWizard):
                 self.cmd.unpick()
                 self.cmd.set_wizard()
                 self.cmd.refresh_wizard()
-                self.cmd.do("_ cmd.clean('%s',message='''Cleaning %s...''',async=1)"%(active_sele,obj_list[0]))
-#                computing.CleanJob(self.cmd,active_sele,
-#                                   message="Cleaning %s..."%obj_list[0])
+                self.cmd.do("_ cmd.clean('%s',message='''Cleaning %s...''',async_=1)"%(active_sele,obj_list[0]))
 
     def do_pick(self, bondFlag):
         if active_sele in self.cmd.get_names("selections"):
@@ -447,7 +438,7 @@ class ValenceWizard(RepeatableActionWizard):
     def do_pick(self, bondFlag):
         self.cmd.select(active_sele, "bymol pk1")
         if bondFlag:
-            if self.order>=0:
+            if int(self.order)>=0:
                 self.cmd.valence(self.order, "pk1", "pk2")
                 self.cmd.h_fill()
             else:
